@@ -123,6 +123,11 @@ def app_setting():
     
     app_settings =  {
                         'banners': banner_file_list,
+                        'message_box_settings': {
+                                                'max_read_count'                : 10,
+                                                'read_interval_in_second'       : 10,
+                                                'list_message_pagination_limit' : 10,
+                                                },
         
                     }
     '''
