@@ -13,7 +13,7 @@ from trexmodel.utils.model.model_util import create_db_client
 from flask.json import jsonify
 from datetime import datetime
 from trexapi.decorators.api_decorators import auth_token_required,\
-    outlet_key_required, test_session_expired
+    outlet_key_required, test_session_expired, device_is_activated
 from trexlib.utils.string_util import is_not_empty
 from trexmodel.models.datastore.customer_models import Customer,\
     CustomerMembership, CustomerTierMembership
@@ -55,6 +55,7 @@ customer_api = Api(customer_api_bp)
 @customer_api_bp.route('/register', methods=['POST'])
 @auth_token_required
 @outlet_key_required
+@device_is_activated
 def create_customer():
     customer_data_in_json   = request.get_json()
     register_customer_form  = CustomerDetailsNewForm(ImmutableMultiDict(customer_data_in_json))
@@ -212,6 +213,7 @@ def create_customer():
 
 @customer_api_bp.route('/reference-code/<ref_code>', methods=['GET'])
 @auth_token_required
+@device_is_activated
 def read_customer(ref_code):
     
     logger.debug('ref_code=%s', ref_code)
@@ -230,6 +232,7 @@ def read_customer(ref_code):
         
             user_details = customer.registered_user_acct
             customer_details_dict = customer.to_dict(date_format="%d-%m-%Y", datetime_format="%d-%m-%Y %H:%M:%S")
+            
             customer_details_dict['customer_key']               = customer.key_in_str
             customer_details_dict['is_email_verified']          = user_details.is_email_verified
             customer_details_dict['is_mobile_phone_verified']   = user_details.is_mobile_phone_verified
@@ -238,7 +241,12 @@ def read_customer(ref_code):
                 customer_details_dict['voucher_summary']            = customer.entitled_voucher_summary
                 del customer_details_dict['entitled_voucher_summary']
             
-            return jsonify(customer_details_dict)
+            customer_details_json =  jsonify(customer_details_dict)
+            
+            
+            logger.debug('customer_details_json=%s', customer_details_json)
+            
+            return customer_details_json
             
         else:
             logger.warn('Customer with reference code (%s) is not found', ref_code)
@@ -249,6 +257,7 @@ def read_customer(ref_code):
     
 @customer_api_bp.route('/customer-key/<customer_key>', methods=['GET'])
 @auth_token_required
+@device_is_activated
 def read_customer_by_customer_key(customer_key):
     
     logger.debug('customer_key=%s', customer_key)
@@ -297,6 +306,7 @@ def read_customer_by_customer_key(customer_key):
 
 @customer_api_bp.route('/customer-key/<customer_key>', methods=['PUT'])
 @auth_token_required
+@device_is_activated
 def update_customer(customer_key):
     customer_data_in_json   = request.get_json()
     updating_customer_form  = CustomerDetailsUpdateForm(ImmutableMultiDict(customer_data_in_json))
@@ -398,6 +408,7 @@ def update_customer(customer_key):
         
 @customer_api_bp.route('/<ref_code>', methods=['DELETE'])
 @auth_token_required 
+@device_is_activated
 def delete_customer(ref_code):
     if is_not_empty(ref_code):
         is_found = False
@@ -418,6 +429,7 @@ def delete_customer(ref_code):
 
 @customer_api_bp.route('/register-as-customer', methods=['POST'])
 @auth_token_required
+@device_is_activated
 def register_user_as_customer():
     user_data_in_json           = request.get_json()
     reference_code              = user_data_in_json.get('reference_code')
@@ -537,6 +549,7 @@ def register_user_as_customer():
 
 @customer_api_bp.route('/search/<limit>', methods=['POST'])
 @auth_token_required
+@device_is_activated
 #@test_session_expired
 def search_customer(limit):
     
@@ -560,6 +573,7 @@ def search_customer(limit):
         logger.debug('acct_id=%s', acct_id)
         logger.debug('name=%s', name)
         logger.debug('email=%s', email)
+        logger.debug('mobile_phone=%s', mobile_phone)
         logger.debug('reference_code=%s', reference_code)
         logger.debug('merchant_reference_code=%s', merchant_reference_code)
         
@@ -578,20 +592,31 @@ def search_customer(limit):
         
             for c in search_results:
                 user_details = c.registered_user_acct
-                customer_details_dict = c.to_dict(date_format="%d-%m-%Y", datetime_format="%d-%m-%Y %H:%M:%S")
+                customer_details_dict = c.to_dict(
+                                            date_format="%d-%m-%Y", 
+                                            datetime_format="%d-%m-%Y %H:%M:%S",
+                                            excluded_dict_properties=['registered_merchant_acct'],
+                                            )
                 customer_details_dict['customer_key']               = c.key_in_str
                 customer_details_dict['is_email_verified']          = user_details.is_email_verified
                 customer_details_dict['is_mobile_phone_verified']   = user_details.is_mobile_phone_verified
                 
                 if 'entitled_voucher_summary' in customer_details_dict:
                     customer_details_dict['voucher_summary']            = c.entitled_voucher_summary
-                    del customer_details_dict['entitled_voucher_summary'] 
+                    #del customer_details_dict['entitled_voucher_summary'] 
                 
                 
+                logger.debug('customer_details_dict=%s', customer_details_dict)
+                
                 customer_list.append(customer_details_dict)
     
-        #return create_rest_message(status_code=StatusCode.OK, customer_list=customer_list)
-        return jsonify(customer_list)
+        #return create_rest_message(status_code=customer_list.OK, customer_list=customer_list)
+        customer_details_list_json =  jsonify(customer_list)
+            
+            
+        logger.debug('customer_details_list_json=%s', customer_details_list_json)
+            
+        return customer_details_list_json
     else:
         error_message = search_customer_form.create_rest_return_error_message()
         return create_rest_message(error_message, status_code=StatusCode.BAD_REQUEST)
