@@ -31,6 +31,9 @@ from flask_babel import gettext
 from trexadmin import conf
 import os
 from trexlib.utils.sms_util import send_sms
+from trexmodel.models.datastore.message_models import Message
+from time import strftime
+from trexlib.utils.common.date_util import from_utc_datetime_to_local_datetime
 
 user_api_bp = Blueprint('user_api_bp', __name__,
                                  template_folder='templates',
@@ -835,7 +838,30 @@ def read_user_acct(reference_code):
             
     else:
         logger.warn('verify_user: user verify input is invalid')
-        return create_rest_message(status_code=StatusCode.BAD_REQUEST)    
+        return create_rest_message(status_code=StatusCode.BAD_REQUEST)  
+    
+@user_api_bp.route('/read-user-new-message-count', methods=['GET'])
+@user_auth_token_required
+def read_user_new_message_count():
+    reference_code = request.headers.get('x-reference-code')
+
+    if is_not_empty(reference_code):
+        db_client = create_db_client(caller_info="read_user_new_message_count")
+        user_acct = None
+        with db_client.context():
+            user_acct = User.get_by_reference_code(reference_code)
+        
+        if user_acct:
+            return create_rest_message(status_code=StatusCode.OK, 
+                                       new_message_count = user_acct.new_message_count
+                                       )
+        else:
+            logger.debug('user account is not found')
+            return create_rest_message(status_code=StatusCode.BAD_REQUEST)
+            
+    else:
+        logger.warn('verify_user: user verify input is invalid')
+        return create_rest_message(status_code=StatusCode.BAD_REQUEST)        
 
 @user_api_bp.route('/joined-brands-list', methods=['GET'])
 @user_auth_token_required
@@ -1258,7 +1284,8 @@ def outlet_reviews():
 def remove_user_voucher(redeem_code):
     if is_not_empty(redeem_code):
         reference_code = request.headers.get('x-reference-code')
-        logger.debug('reference_code=%s', reference_code)
+        logger.info('reference_code=%s', reference_code)
+        logger.info('redeem_code=%s', redeem_code)
         db_client = create_db_client(caller_info="remove_user_voucher")
         with db_client.context():
             customer_voucher    = CustomerEntitledVoucher.get_by_redeem_code(redeem_code)
@@ -1268,12 +1295,16 @@ def remove_user_voucher(redeem_code):
                 customer_voucher.remove()  
                 customer = customer_voucher.entitled_customer_acct
                 customer.update_after_removed_voucher(customer_voucher)
-                
-        if customer_voucher:        
+            else:
+                logger.info('voucher is not found')    
+
+        if customer_voucher and customer_voucher.is_removed:        
             return create_rest_message(status_code=StatusCode.OK)
         else:
+            logger.info('Invalid voucher redeem code')
             return create_rest_message('Invalid voucher redeem code', status_code=StatusCode.BAD_REQUEST)
     else:
+        logger.info('Missing voucher redeem code')
         return create_rest_message('Missing voucher redeem code', status_code=StatusCode.BAD_REQUEST)
 
 def send_email_verification_code_email(email, verification_code, request_id):
@@ -1387,4 +1418,101 @@ def send_reset_password_request_sms(mobile_phone, verification_code, request_id)
         send_sms(to_number=mobile_phone, body=message)
     else:
         logger.debug('not send sms for development or local mode')
+        
+@user_api_bp.route('/list-user-messages', methods=['GET'])
+@user_auth_token_required
+def list_user_messages():
+    reference_code = request.headers.get('x-reference-code')
     
+    limit           = request.args.get('limit')
+    start_cursor    = request.args.get('start_cursor')
+    
+    logger.debug('limit=%s', limit)
+    logger.debug('start_cursor=%s', start_cursor)
+    
+    if is_not_empty(reference_code):
+        db_client = create_db_client(caller_info="list_user_messages")
+        user_acct               = None
+        user_messages_list      = []
+        result_data             = {}
+        
+        if is_not_empty(limit):
+            limit = int(limit)
+        
+        with db_client.context():
+            user_acct = User.get_by_reference_code(reference_code)
+        
+        if user_acct:
+            logger.debug('verify_user: found user account by reference_code=%s', reference_code)
+            
+            
+            
+            with db_client.context():
+                (messages_list, next_cursor) = Message.list_paginated_by_user_account(user_acct, start_cursor=start_cursor, limit=limit)
+                
+                for message in messages_list:
+                    logger.debug('message.created_datetime=%s', message.created_datetime)
+                    local_datetime = from_utc_datetime_to_local_datetime(message.created_datetime, country_code=user_acct.country,)
+                    
+                    user_messages_list.append(
+                                {
+                                'message_key'       : message.key_in_str,
+                                'message_title'     : message.title,
+                                'message_category'  : message.message_category,
+                                'message_content'   : message.message_content,
+                                'message_data'      : message.message_data,
+                                'message_status'    : message.status,
+                                #'message_status'    : 'n',
+                                'created_datetime'  : local_datetime.strftime('%d-%m-%Y %H:%M'),
+                                }
+                                )
+                    
+                
+                result_data= {
+                                'result'        : user_messages_list,
+                                'count'         : len(user_messages_list),
+                                }
+                logger.debug('result_data=%s', result_data)
+                  
+                if is_not_empty(next_cursor):
+                    result_data['next_cursor'] = next_cursor  
+        
+        
+        
+        return create_rest_message(status_code=StatusCode.OK,
+                                   **result_data, 
+                                   )
+    else:
+        return create_rest_message(status_code=StatusCode.BAD_REQUEST)          
+    
+
+@user_api_bp.route('/read-user-message', methods=['POST'])
+@user_auth_token_required
+def read_user_message():
+    message_key = request.args.get('message_key') or request.form.get('message_key') or request.json.get('message_key')
+    
+    if is_not_empty(message_key):
+        db_client = create_db_client(caller_info="update_user_message_as_read")
+        
+        with db_client.context():
+            Message.update_read(message_key)
+
+        return create_rest_message(status_code=StatusCode.ACCEPTED,)
+    else:
+        return create_rest_message(status_code=StatusCode.BAD_REQUEST)
+ 
+@user_api_bp.route('/delete-user-message', methods=['DELETE'])
+@user_auth_token_required
+def delete_user_message_as_read():
+    message_key = request.args.get('message_key') or request.form.get('message_key') or request.json.get('message_key')
+    
+    if is_not_empty(message_key):
+        db_client = create_db_client(caller_info="delete_user_message_as_read")
+        
+        with db_client.context():
+            Message.update_delete(message_key)
+            
+        return create_rest_message(status_code=StatusCode.ACCEPTED,)
+    else:
+        return create_rest_message(status_code=StatusCode.BAD_REQUEST)    
+    
\ No newline at end of file
