@@ -10,7 +10,7 @@ from trexlib.utils.log_util import get_tracelog
 from trexmodel.utils.model.model_util import create_db_client
 from datetime import datetime, timedelta
 from trexapi.decorators.api_decorators import auth_token_required,\
-    user_auth_token_required
+    user_auth_token_required, device_is_activated
 from trexlib.utils.string_util import is_not_empty, is_empty
 from trexmodel.models.datastore.customer_models import Customer
 from trexadmin.libs.http import create_rest_message
@@ -48,8 +48,9 @@ logger = logging.getLogger('api')
 def ping():
     return create_rest_message('Pong', status_code=StatusCode.OK)
 
-@voucher_api_bp.route('/voucher/<redeem_code>/details', methods=['GET'])
+@voucher_api_bp.route('/voucher/<redeem_code>/details', methods=['POST','GET'])
 @auth_token_required
+@device_is_activated
 def read_voucher(redeem_code):
     if is_not_empty(redeem_code):
         voucher_details = None
@@ -96,6 +97,7 @@ def read_voucher(redeem_code):
     
 @voucher_api_bp.route('/voucher/redeem', methods=['post'])
 @auth_token_required
+@device_is_activated
 def redeem_voucher():
     
     redeem_voucher_data_in_json   = request.get_json()
@@ -203,6 +205,7 @@ def redeem_voucher():
         
 @voucher_api_bp.route('/voucher/<redeem_code>/remove', methods=['DELETE'])
 @auth_token_required
+@device_is_activated
 def remove_voucher(redeem_code):
     
     remove_voucher_data_in_json   = request.get_json()
@@ -310,15 +313,20 @@ def remove_user_voucher(redeem_code):
         db_client = create_db_client(caller_info="remove_user_voucher")
         with db_client.context():
             customer_voucher    = CustomerEntitledVoucher.get_by_redeem_code(redeem_code)
-            '''
+            
             if customer_voucher: 
+                
                 customer_voucher.remove()  
                 customer = customer_voucher.entitled_customer_acct
                 customer.update_after_removed_voucher(customer_voucher)
-            '''    
-        if customer_voucher:        
-            return create_rest_message(status_code=StatusCode.BAD_REQUEST)
+            else:
+                logger.info('voucher is not found')    
+               
+        if customer_voucher and customer_voucher.is_removed:        
+        
+            return create_rest_message(status_code=StatusCode.OK)
         else:
+            logger.info('Invalid voucher redeem code')
             return create_rest_message('Invalid voucher redeem code', status_code=StatusCode.BAD_REQUEST)
     else:
         return create_rest_message('Missing voucher redeem code', status_code=StatusCode.BAD_REQUEST)
