@@ -100,8 +100,7 @@ class CustomerSearchForm(ValidationBaseForm):
     mobile_phone                    = StringField('Mobile Phone', [
                                         validators.Optional(),
                                         custom_validator.RequiredIfOtherFieldsValueIsEmpty(
-                                                        ['name', 'email', 'reference_code', 
-                                                         'merchant_reference_code', ],
+                                                        ['name', 'email', 'reference_code', 'merchant_reference_code', ],
                                                         message=gettext("Either one input is required")),
                                         
                                         ]
@@ -110,17 +109,16 @@ class CustomerSearchForm(ValidationBaseForm):
     reference_code                  = StringField('Reference code', [
                                         validators.Optional(),
                                         custom_validator.RequiredIfOtherFieldsValueIsEmpty(
-                                                        ['mobile_phone', 'email', 'name', 'reference_code',  
-                                                         ],
+                                                        ['mobile_phone', 'email', 'name', 'merchant_reference_code',  ],
                                                         message=gettext("Either one input is required")),
-                                        validators.Length(max=16, message="Member code length must not more than 16 characters")
+                                        validators.Length(max=16, message="Reference code length must not more than 16 characters")
                                         ]
                                         )
     
     merchant_reference_code         = StringField('Member code', [
                                         validators.Optional(),
                                         custom_validator.RequiredIfOtherFieldsValueIsEmpty(
-                                                        ['mobile_phone', 'email', 'name', 'reference_code',  
+                                                        ['mobile_phone', 'email', 'name', 'merchant_reference_code', 
                                                          ],
                                                         message=gettext("Either one input is required")),
                                         validators.Length(max=16, message="Member code length must not more than 16 characters")
