@@ -39,6 +39,7 @@ from trexmodel.models.datastore.redeem_models import CustomerRedemption
 from trexlib.utils.string_util import is_not_empty
 from trexlib.utils.log_util import get_tracelog
 from trexmodel.models.datastore.lucky_draw_models import LuckyDrawTicket
+from trexmodel.models.datastore.message_model_helper import create_transaction_message
 
 logger = logging.getLogger('debug')
 #logger = logging.getLogger('debug')
@@ -106,6 +107,7 @@ def create_reward_transaction(customer, transact_outlet=None, sales_amount=.0, t
         logger.debug('trigger_check_reward_success=%s', trigger_check_reward_success)
         
         if trigger_check_reward_success:
+            create_transaction_message(customer_transaction)
             create_merchant_customer_transaction_upstream_for_merchant(customer_transaction, streamed_datetime=transact_datetime)
         
         return customer_transaction
@@ -125,6 +127,7 @@ def give_reward_from_sales_transaction(customer, sales_transaction):
         logger.debug('trigger_check_reward_success=%s', trigger_check_reward_success)
         
         if trigger_check_reward_success:
+            create_transaction_message(customer_transaction)
             create_merchant_customer_transaction_upstream_for_merchant(customer_transaction, streamed_datetime=sales_transaction.transact_datetime)
         
         return customer_transaction
@@ -546,7 +549,10 @@ def check_spending_reward_for_transaction(customer_acct, transaction_details, pr
 def check_entitled_lucky_draw_ticket_for_transaction(customer_acct, merchant_acct, transaction_details):
     
     if merchant_acct.lucky_draw_program_count>0:
-        entries_list = LuckyDrawTicket.create_for_customer_from_sales_amount(customer_acct, sales_amount=transaction_details.transact_amount, merchant_acct=merchant_acct, transact_outlet=transaction_details.transact_outlet_entity)
+        entries_list = LuckyDrawTicket.create_for_customer_from_sales_amount(customer_acct, 
+                                                                             sales_amount=transaction_details.transact_amount, 
+                                                                             merchant_acct=merchant_acct, 
+                                                                             transact_outlet=transaction_details.transact_outlet_entity)
         ticket_configurations_list = []
         logger.debug('entries_list count=%d', len(entries_list))
         
@@ -1022,6 +1028,7 @@ def create_topup_prepaid_transaction(customer, prepaid_program, topup_outlet=Non
             
             update_customer_kpi_summary_and_transact_summary(customer, customer_transaction)
             
+            create_transaction_message(customer_transaction)
             create_merchant_customer_prepaid_upstream_for_merchant(customer_transaction, prepaid_topup_reward, streamed_datetime=transact_datetime)
             create_merchant_customer_transaction_upstream_for_merchant(customer_transaction, streamed_datetime=transact_datetime)
         
